%{

#include "globals.h"
#include "y.tab.h"

extern int  yylval;

%}

delim	[ \t\n\r]
ws		{delim}+
letter	[a-zA-Z]
digit	[0-9]
id		{letter}({letter}|{digit})*
num		{digit}+

%%

{ws}	{ ; }
begin 	{ return(BEG); }
end		{ return(END); }
var		{ return(VAR); }
if		{ return(IF); }
then	{ return(THEN); }
else	{ return(ELSE); }
fi		{ return(FI); }
,		{ return(COMMA); }
;		{ return(SEMI); }
:=		{ return(ASSIGN); }
"("		{ return(OPAREN); }
")"		{ return(CPAREN); }
=		{ return(EQ); }
!=		{ return(NE); }
"<"		{ return(LT); }
">"		{ return(GT); }
"<="	{ return(LE); }
">="	{ return(GE); }
while	{ return(WHILE); }
do		{ return(DO); }
od		{ return(OD); }
skip	{ return(SKIP); }
read	{ return(READ); }
write	{ return(WRITE); }
or		{ return(OR); }
and		{ return(AND); }
!		{ return(NOT); }
"+"		{ return(PLUS); }
"-"		{ return(MINUS); }
"*"		{ return(MULT); }
"/"		{ return(DIV); }
"%"		{ return(MOD); }
true	{ return(TRUE); }
false	{ return(FALSE); }
{num}	{ yylval = atoi(yytext); return(NUMBER); }
{id}	{ return(ID); }
.		{ return(ERR); }

%%

/*
int main()
{
	int tokens = 0, done = 0;

	while(!done)
	{
		int currentToken = yylex();
		switch (currentToken)
		{
			case ID:
				printf("identifier\t%s\n", yytext);
				break;
			case NUMBER:
				printf("number\t\t%s\n", yytext);
				break;
			case COMMA:
				printf("comma\n");
				break;
			case SEMI:
				printf("semicolon\n");
				break;
			case ASSIGN:
				printf("assignment\n");
				break;
			case OPAREN:
				printf("open-parenthesis\n");
				break;
			case CPAREN:
				printf("close-parenthesis\n");
				break;
			case EQ:
				printf("equal to\n");
				break;
			case NE:
				printf("not equal to\n");
				break;
			case LT:
				printf("less than\n");
				break;
			case GT:
				printf("greater than\n");
				break;
			case LE:
				printf("less than or equal to\n");
				break;
			case GE:
				printf("greater than or equal to\n");
				break;
			case NOT:
				printf("not\n");
				break;
			case PLUS:
				printf("plus\n");
				break;
			case MINUS:
				printf("minus\n");
				break;
			case MULT:
				printf("multiply\n");
				break;
			case DIV:
				printf("divide\n");
				break;
			case MOD:
				printf("mod\n");
				break;
			case ERR:
				printf("ERROR: <%s> not recognised\n", yytext);
				break;
			case ENDFILE:
				printf("Done. %d tokens processed.\n\n", tokens);
				done = 1;
			default:
				printf("%s\n", yytext);
		}
		tokens++;
	}
	return 0;
}
*/
